@@ -112,12 +112,12 @@ nixtla_client_historic <- function(df, freq=NULL, id_col=NULL, time_col="ds", ta
   }
 
   # Make request ----
-  url <- "https://api.nixtla.io/v2/historic_forecast"
-  req <- httr2::request(url) |>
+  setup <- .get_client_steup()
+  req <- httr2::request(paste0(setup$base_url, "v2/historic_forecast")) |>
     httr2::req_headers(
       "accept" = "application/json",
       "content-type" = "application/json",
-      "authorization" = paste("Bearer", .get_api_key())
+      "authorization" = paste("Bearer", setup$api_key)
     ) |>
     httr2::req_user_agent("nixtlar") |>
     httr2::req_body_json(data = payload) |>
