@@ -1,5 +1,7 @@
 #' Set 'API' key in global environment
 #'
+#' This function will be deprecated in future versions. Please use `nixtla_client_setup` instead.
+#'
 #' @param api_key The user's 'API' key. Get yours here: https://dashboard.nixtla.io/
 #'
 #' @return A message indicating the 'API' key has been set in the global environment.
@@ -7,10 +9,9 @@
 #'
 #' @examples
 #' \dontrun{
-#'   nixtlar::nixtla_set_api_key("YOUR_API_KEY")
+#'   nixtlar::nixtla_set_api_key("Your API key")
 #' }
 #'
 nixtla_set_api_key <- function(api_key) {
-  options("NIXTLA_API_KEY"=api_key)
-  message("API key has been set for the current session.")
+  nixtla_client_setup(base_url = NULL, api_key = api_key)
 }
